@@ -34,7 +34,7 @@ class Answer(JSONModel):
 			self.owner_id = json.owner['user_id']
 			self.owner_info = tuple(json.owner.values())
 
-		self.creation_date = datetime.date.fromtimestamp(json.creation_date)
+		self.creation_date = datetime.datetime.fromtimestamp(json.creation_date)
 
 		if hasattr(json, 'last_edit_date'):
 			self.last_edit_date = datetime.date.fromtimestamp(json.last_edit_date)
@@ -86,10 +86,12 @@ class Question(JSONModel):
 		self.timeline = StackExchangeLazySequence(TimelineEvent, None, site, json.question_timeline_url, self._up('timeline'))
 		self.revisions = StackExchangeLazySequence(PostRevision, None, site, 'revisions/%s' % self.id, self._up('revisions'), 'revisions')
 
+		self.creation_date = datetime.datetime.fromtimestamp(json.creation_date)
 		self.comments_url = json.question_comments_url
 		self.comments = StackExchangeLazySequence(Comment, None, site, self.comments_url, self._up('comments'))
 
 		self.answers_url = json.question_answers_url
+
 		if hasattr(json, 'answers'):
 			self.answers = [Answer(x, site) for x in json.answers]
 		else:
@@ -126,7 +128,7 @@ class Comment(JSONModel):
 	def _extend(self, json, site):
 		self.id = json.comment_id
 
-		self.creation_date = datetime.date.fromtimestamp(json.creation_date)
+		self.creation_date = datetime.datetime.fromtimestamp(json.creation_date)
 
 		if hasattr(json, 'owner'):
 			self.owner_id = json.owner['owner_id'] if 'owner_id' in json.owner else json.owner['user_id']
@@ -175,7 +177,7 @@ class PostRevision(JSONModel):
 				'revision_number', 'title', 'set_community_wiki', 'post_id', 'last_tags', 'tags')
 
 	def _extend(self, json, site):
-		self.creation_date = datetime.date.fromtimestamp(json.creation_date)
+		self.creation_date = datetime.datetime.fromtimestamp(json.creation_date)
 		self.revision_type = RevisionType.from_string(json.revision_type)
 
 		part = json.user
@@ -207,7 +209,7 @@ class TagSynonym(JSONModel):
 	transfer = ('from_tag', 'to_tag', 'applied_count')
 
 	def _extend(self, json, site):
-		self.creation_date = datetime.date.fromtimestamp(json.creation_date)
+		self.creation_date = datetime.datetime.fromtimestamp(json.creation_date)
 		self.last_applied_date = datetime.date.fromtimestamp(json.last_applied_date)
 
 	def __repr__(self):
@@ -308,7 +310,7 @@ class TimelineEvent(JSONModel):
 
 		if self.timeline_type in self._post_related:
 			self.post_type = PostType.from_string(json.post_type)
-			self.creation_date = datetime.date.fromtimestamp(json.creation_date)
+			self.creation_date = datetime.datetime.fromtimestamp(json.creation_date)
 
 	def _get_post(self):
 		if self.timeline_type in self._post_related:
@@ -377,7 +379,7 @@ class User(JSONModel):
 	def _extend(self, json, site):
 		self.id = json.user_id
 		self.type = Enumeration.from_string(json.user_type, UserType)
-		self.creation_date = datetime.date.fromtimestamp(json.creation_date)
+		self.creation_date = datetime.datetime.fromtimestamp(json.creation_date)
 		self.last_access_date = datetime.date.fromtimestamp(json.last_access_date)
 		self.reputation = FormattedReputation(json.reputation)
 
@@ -553,7 +555,11 @@ through here."""
 
 		new_params = {}
 		for k, v in params.iteritems():
-			new_params[k] = self._kw_to_str(v)
+			if k in ('fromdate', 'todate'):
+				# bit of a HACKish workaround for a reported issue; force to an integer
+				new_params[k] = str(int(v))
+			else:
+				new_params[k] = self._kw_to_str(v)
 		if self.app_key != None:
 			new_params['key'] = self.app_key
 
@@ -620,9 +626,13 @@ through here."""
 		u, = self.users((nid,), **kw)
 		return u
 
-	def users(self, ids, **kw):
+	def users(self, ids=[], **kw):
 		"""Retrieves a list of the users with the IDs specified in the `ids' parameter."""
 		return self._get(User, ids, 'users', kw)
+	
+	def users_by_name(self, name, **kw):
+		kw['filter'] = name
+		return self.users(**kw)
 
 	def moderators(self, **kw):
 		"""Retrieves a list of the moderators on the site."""
@@ -701,9 +711,9 @@ unlike on the actual site, you will receive an error rather than a redirect to t
 					return badge
 			return None
 
-	def priveleges(self):
-		"""Returns all the priveleges a user can have on the site."""
-		return self.build('priveleges', Privelege, 'priveleges', kw)
+	def privileges(self):
+		"""Returns all the privileges a user can have on the site."""
+		return self.build('privileges', Privelege, 'privileges', kw)
 
 	def all_nontag_badges(self, **kw):
 		"""Returns the set of all badges which are not tag-based."""
